/* Generated automatically by the program `gencodes'
   from the machine description file `md'.  */

#ifndef GCC_INSN_CODES_H
#define GCC_INSN_CODES_H

enum insn_code {
  CODE_FOR_nothing = 0,
  CODE_FOR_bswapsi2 = 1,
  CODE_FOR_bswaphi2 = 2,
  CODE_FOR_addsf3 = 3,
  CODE_FOR_subsf3 = 4,
  CODE_FOR_mulsf3 = 5,
  CODE_FOR_divsf3 = 6,
  CODE_FOR_sqrtsf2 = 7,
  CODE_FOR_floatsisf2 = 8,
  CODE_FOR_fix_truncsfsi2 = 9,
  CODE_FOR_adddf3 = 10,
  CODE_FOR_subdf3 = 11,
  CODE_FOR_muldf3 = 12,
  CODE_FOR_divdf3 = 13,
  CODE_FOR_sqrtdf2 = 14,
  CODE_FOR_floatdidf2 = 15,
  CODE_FOR_fix_truncdfdi2 = 16,
  CODE_FOR_addsi3 = 17,
  CODE_FOR_adddi3_int = 18,
  CODE_FOR_subsi3 = 21,
  CODE_FOR_iprefetch = 22,
  CODE_FOR_subdi316imm = 23,
  CODE_FOR_subsidi3 = 24,
  CODE_FOR_subdi3_small = 25,
  CODE_FOR_mulsi3 = 26,
  CODE_FOR_mulsidi3 = 27,
  CODE_FOR_umulsidi3 = 28,
  CODE_FOR_usmulsidi3 = 29,
  CODE_FOR_divsi3_internal = 33,
  CODE_FOR_udivsi3 = 34,
  CODE_FOR_negsi2 = 35,
  CODE_FOR_negsi_long = 36,
  CODE_FOR_negdi2_long = 37,
  CODE_FOR_negdi2 = 38,
  CODE_FOR_one_cmplsi2 = 39,
  CODE_FOR_anddi3imm16 = 42,
  CODE_FOR_anddi3 = 43,
  CODE_FOR_andsi3 = 44,
  CODE_FOR_iordi3imm16 = 45,
  CODE_FOR_iordi3 = 46,
  CODE_FOR_iorsi3 = 47,
  CODE_FOR_xordi3imm16 = 48,
  CODE_FOR_xordi3 = 49,
  CODE_FOR_xorsi3 = 50,
  CODE_FOR_zero_extendhisi2 = 51,
  CODE_FOR_zero_extendqihi2 = 52,
  CODE_FOR_zero_extendqisi2 = 53,
  CODE_FOR_zero_extendhidi2 = 54,
  CODE_FOR_zero_extendsidi2 = 55,
  CODE_FOR_zero_extendqidi2 = 56,
  CODE_FOR_extendqisi2 = 57,
  CODE_FOR_extendhisi2 = 58,
  CODE_FOR_extendhidi2 = 59,
  CODE_FOR_extendsidi2_long = 60,
  CODE_FOR_extendsidi2 = 61,
  CODE_FOR_movdi_status = 62,
  CODE_FOR_movdi_long_int = 68,
  CODE_FOR_movsi_status = 69,
  CODE_FOR_movsi4_rev = 75,
  CODE_FOR_ashlsi3_bshift = 81,
  CODE_FOR_ashldi3_long = 82,
  CODE_FOR_ashldi3_const = 83,
  CODE_FOR_ashldi3_reg = 84,
  CODE_FOR_ashrdi3_long = 91,
  CODE_FOR_ashrdi3_const = 92,
  CODE_FOR_ashrdi3_reg = 93,
  CODE_FOR_lshrdi3_long = 99,
  CODE_FOR_lshrdi3_const = 100,
  CODE_FOR_lshrdi3_reg = 101,
  CODE_FOR_seq_internal_pat_long = 107,
  CODE_FOR_sne_internal_pat_long = 108,
  CODE_FOR_seq_internal_pat = 109,
  CODE_FOR_sne_internal_pat = 110,
  CODE_FOR_cstoresf4 = 111,
  CODE_FOR_cstoredf4 = 112,
  CODE_FOR_branch_zero_64 = 113,
  CODE_FOR_long_branch_zero = 114,
  CODE_FOR_branch_zero = 115,
  CODE_FOR_branch_compare64 = 116,
  CODE_FOR_long_branch_compare = 117,
  CODE_FOR_branch_compare = 118,
  CODE_FOR_jump_64 = 119,
  CODE_FOR_jump = 120,
  CODE_FOR_indirect_jump_internal1 = 121,
  CODE_FOR_tablejump_internal1 = 122,
  CODE_FOR_tablejump_internal2 = 123,
  CODE_FOR_return_internal = 128,
  CODE_FOR_simple_return_internal = 129,
  CODE_FOR_blockage = 130,
  CODE_FOR_call_internal_plt_64 = 131,
  CODE_FOR_call_internal_plt = 132,
  CODE_FOR_call_internal1_64 = 133,
  CODE_FOR_call_internal1 = 134,
  CODE_FOR_call_value_intern_plt_64 = 135,
  CODE_FOR_call_value_intern_plt = 136,
  CODE_FOR_call_value_intern_64 = 137,
  CODE_FOR_call_value_intern = 138,
  CODE_FOR_nop = 139,
  CODE_FOR_trap = 140,
  CODE_FOR_set_got = 141,
  CODE_FOR_set_text = 142,
  CODE_FOR_clzsi2 = 143,
  CODE_FOR_extv_32 = 144,
  CODE_FOR_insv_32 = 145,
  CODE_FOR_atomic_compare_and_swapsi = 146,
  CODE_FOR_adddi3 = 147,
  CODE_FOR_subdi3 = 148,
  CODE_FOR_divsi3 = 149,
  CODE_FOR_one_cmpldi2 = 150,
  CODE_FOR_movdi = 151,
  CODE_FOR_movsi = 152,
  CODE_FOR_movhi = 153,
  CODE_FOR_movqi = 154,
  CODE_FOR_cpymemsi = 155,
  CODE_FOR_movsf = 156,
  CODE_FOR_movdf = 157,
  CODE_FOR_ashlsi3 = 158,
  CODE_FOR_ashldi3 = 159,
  CODE_FOR_ashrdi3 = 160,
  CODE_FOR_ashrsi3 = 161,
  CODE_FOR_lshrdi3 = 162,
  CODE_FOR_lshrsi3 = 163,
  CODE_FOR_cstoresi4 = 164,
  CODE_FOR_cbranchsi4 = 165,
  CODE_FOR_cbranchsi4_reg = 166,
  CODE_FOR_cbranchsf4 = 167,
  CODE_FOR_condjump = 168,
  CODE_FOR_cbranchdi4 = 169,
  CODE_FOR_cbranchdi4_reg = 170,
  CODE_FOR_cbranchdf4 = 171,
  CODE_FOR_indirect_jump = 172,
  CODE_FOR_tablejump = 173,
  CODE_FOR_tablejump_internal3 = 174,
  CODE_FOR_tablejump_internal4 = 175,
  CODE_FOR_prologue = 176,
  CODE_FOR_epilogue = 177,
  CODE_FOR_allocate_stack = 178,
  CODE_FOR_save_stack_block = 179,
  CODE_FOR_restore_stack_block = 180,
  CODE_FOR_return = 181,
  CODE_FOR_simple_return = 182,
  CODE_FOR_call = 183,
  CODE_FOR_call_internal0 = 184,
  CODE_FOR_call_internal_plt0 = 185,
  CODE_FOR_call_value = 186,
  CODE_FOR_call_value_internal = 187,
  CODE_FOR_call_value_intern_plt0 = 188,
  CODE_FOR_untyped_call = 189,
  CODE_FOR_eh_return = 190,
  CODE_FOR_extvsi = 191,
  CODE_FOR_insvsi = 192
};

const unsigned int NUM_INSN_CODES = 193;
#endif /* GCC_INSN_CODES_H */
