/* Generated automatically by the program `genconstants'
   from the machine description file `md'.  */

#ifndef GCC_INSN_CONSTANTS_H
#define GCC_INSN_CONSTANTS_H

#define UNSPECV_CAS_MEM 203
#define MB_PIPE_5 1
#define R_IR 14
#define MB_PIPE_3 0
#define UNSPECV_CAS_BOOL 201
#define R_GOT 20
#define R_TMP 18
#define UNSPEC_TEXT 108
#define R_DR 16
#define MB_PIPE_8 2
#define UNSPEC_GOTOFF 102
#define R_Z 0
#define R_ER 17
#define UNSPEC_SET_GOT 101
#define UNSPEC_CMPU 105
#define UNSPECV_CAS_VAL 202
#define UNSPEC_SET_TEXT 107
#define R_SP 1
#define UNSPEC_PLT 103
#define R_SR 15
#define UNSPEC_TLS 106
#define UNSPEC_CMP 104

enum unspec {
  UNSPEC_IPREFETCH = 0
};
#define NUM_UNSPEC_VALUES 1
extern const char *const unspec_strings[];

#endif /* GCC_INSN_CONSTANTS_H */
